import std/[paths, times]
import namespaced_logging

import ./[db, models]

type
  MediaLibrary* = ref object
    db: WdiwtltDb
    libraryRoot: Path

proc clean*(lib: MediaLibrary) =
  removeEmptyAlbums(lib.db)
  removeEmptyArtists(lib.db)
  removeEmptyPlaylists(lib.db)

  let expirationDate = now() - weeks(1)

  let expiredPlaylists = lib.db.findPlaylstsWhere(
    "user_created = false AND last_used_at < ?",
    [expirationDate])

  let expiredBookmarks = lib.db.findBookmarksWhere(
    "user_created = false AND last_used_at < ?",
    [expirationDate])

  expiredPlaylists.applyIt(lib.db.deletePlaylist(it.id))
  expiredBookmarks.applyIt(lib.db.deleteBookmark(it.id))

proc rescanLibrary*(lib: MediaLibrary) =
  # TODO: Implement this. Below is AI-generated code.
  let mediaFiles = lib.db.getAllMediaFiles()
  for mf in mediaFiles:
    let filePath = lib.libraryRoot / mf.filePath
    if not filePath.existsFile:
      lib.db.deleteMediaFile(mf.id)
      continue

    let fileHash = filePath.hashFile
    if fileHash != mf.fileHash:
      lib.db.updateMediaFile(mf.id, fileHash: fileHash)
